==> jc-1.4.0.tar.gz: soot/tagkit/GenericAttribute.h <==
// public class soot.tagkit.GenericAttribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7a08964f7e344004 soot_tagkit_GenericAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_GenericAttribute_H_
#define _JC_soot_tagkit_GenericAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_tagkit_GenericAttribute$sub_refs	_jc_soot_tagkit_GenericAttribute$sub_refs;
typedef struct _jc_soot_tagkit_GenericAttribute$sub_nonrefs	_jc_soot_tagkit_GenericAttribute$sub_nonrefs;
typedef struct _jc_soot_tagkit_GenericAttribute$refs	_jc_soot_tagkit_GenericAttribute$refs;
typedef struct _jc_soot_tagkit_GenericAttribute$nonrefs	_jc_soot_tagkit_GenericAttribute$nonrefs;
typedef struct _jc_soot_tagkit_GenericAttribute$object	_jc_soot_tagkit_GenericAttribute$object;

typedef const struct _jc_soot_tagkit_GenericAttribute$vmethods	_jc_soot_tagkit_GenericAttribute$vmethods;
typedef const struct _jc_soot_tagkit_GenericAttribute$vtable	_jc_soot_tagkit_GenericAttribute$vtable;
typedef const struct _jc_soot_tagkit_GenericAttribute$vtype	_jc_soot_tagkit_GenericAttribute$vtype;

// Constructors
extern void _jc_soot_tagkit_GenericAttribute$method$_init$8978305ea064370f(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_GenericAttribute$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);
extern struct _jc_object *_jc_soot_tagkit_GenericAttribute$method$getUnitBoxes$63a3cb25489f231d(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);
extern _jc_byte_array *_jc_soot_tagkit_GenericAttribute$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);
extern void _jc_soot_tagkit_GenericAttribute$method$setValue$ab2460f8c5636eee(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *, struct _jc_byte_array *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_GenericAttribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$getUnitBoxes$63a3cb25489f231d;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$setValue$ab2460f8c5636eee;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_GenericAttribute$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);
	struct _jc_object	*(*getUnitBoxes$63a3cb25489f231d)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);
	void	(*setValue$ab2460f8c5636eee)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *, struct _jc_byte_array *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *);
};

// Vtable
struct _jc_soot_tagkit_GenericAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_GenericAttribute$vmethods	soot_tagkit_GenericAttribute;
};

// Vtype
struct _jc_soot_tagkit_GenericAttribute$vtype {
	_jc_type			type;
	_jc_soot_tagkit_GenericAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_GenericAttribute$sub_refs {
	struct _jc_java_lang_String$object	*mName;
	_jc_byte_array	*mValue;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_GenericAttribute$refs {
    _jc_soot_tagkit_GenericAttribute$sub_refs	soot_tagkit_GenericAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_GenericAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_GenericAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_GenericAttribute$sub_nonrefs	soot_tagkit_GenericAttribute;
};

// Object instance structure
struct _jc_soot_tagkit_GenericAttribute$object {
	_jc_soot_tagkit_GenericAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_GenericAttribute$vtype	*vtype;
	_jc_soot_tagkit_GenericAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_GenericAttribute$vtype _jc_soot_tagkit_GenericAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_GenericAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_GenericAttribute$class_object;

#endif	/* _JC_soot_tagkit_GenericAttribute_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/GenericAttribute.h <==
// public class soot.tagkit.GenericAttribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a08964f7e344004 soot_tagkit_GenericAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_GenericAttribute_H_
#define _JC_soot_tagkit_GenericAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_tagkit_GenericAttribute$sub_refs	_jc_soot_tagkit_GenericAttribute$sub_refs;
typedef struct _jc_soot_tagkit_GenericAttribute$sub_nonrefs	_jc_soot_tagkit_GenericAttribute$sub_nonrefs;
typedef struct _jc_soot_tagkit_GenericAttribute$refs	_jc_soot_tagkit_GenericAttribute$refs;
typedef struct _jc_soot_tagkit_GenericAttribute$nonrefs	_jc_soot_tagkit_GenericAttribute$nonrefs;
typedef struct _jc_soot_tagkit_GenericAttribute$object	_jc_soot_tagkit_GenericAttribute$object;

typedef const struct _jc_soot_tagkit_GenericAttribute$vmethods	_jc_soot_tagkit_GenericAttribute$vmethods;
typedef const struct _jc_soot_tagkit_GenericAttribute$vtable	_jc_soot_tagkit_GenericAttribute$vtable;
typedef const struct _jc_soot_tagkit_GenericAttribute$vtype	_jc_soot_tagkit_GenericAttribute$vtype;

// Constructors
extern void _jc_soot_tagkit_GenericAttribute$method$_init$8978305ea064370f(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_GenericAttribute$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_tagkit_GenericAttribute$method$getUnitBoxes$63a3cb25489f231d(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_GenericAttribute$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;
extern void _jc_soot_tagkit_GenericAttribute$method$setValue$ab2460f8c5636eee(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_GenericAttribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$getUnitBoxes$63a3cb25489f231d;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$setValue$ab2460f8c5636eee;
extern _jc_method _jc_soot_tagkit_GenericAttribute$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_GenericAttribute$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUnitBoxes$63a3cb25489f231d)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;
	void	(*setValue$ab2460f8c5636eee)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_GenericAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_GenericAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_GenericAttribute$vmethods	soot_tagkit_GenericAttribute;
};

// Vtype
struct _jc_soot_tagkit_GenericAttribute$vtype {
	_jc_type			type;
	_jc_soot_tagkit_GenericAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_GenericAttribute$sub_refs {
	struct _jc_java_lang_String$object	*mName;
	_jc_byte_array	*mValue;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_GenericAttribute$refs {
    _jc_soot_tagkit_GenericAttribute$sub_refs	soot_tagkit_GenericAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_GenericAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_GenericAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_GenericAttribute$sub_nonrefs	soot_tagkit_GenericAttribute;
};

// Object instance structure
struct _jc_soot_tagkit_GenericAttribute$object {
	_jc_soot_tagkit_GenericAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_GenericAttribute$vtype	*vtype;
	_jc_soot_tagkit_GenericAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_GenericAttribute$vtype _jc_soot_tagkit_GenericAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_GenericAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_GenericAttribute$class_object;

#endif	/* _JC_soot_tagkit_GenericAttribute_H_ */
